HttpBodyFileUpload class

A wrapper around a file upload.

Properties

content → dynamic
The content of the file.
final
contentType → ContentType?
The ContentType of the uploaded file.
final
filename → String
The filename of the uploaded file.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited